package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.Cooperate;

/**
 * 企业合作Service接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface ICooperateService 
{
    /**
     * 查询企业合作
     * 
     * @param id 企业合作主键
     * @return 企业合作
     */
    public Cooperate selectCooperateById(Long id);

    /**
     * 查询企业合作列表
     * 
     * @param cooperate 企业合作
     * @return 企业合作集合
     */
    public List<Cooperate> selectCooperateList(Cooperate cooperate);

    /**
     * 新增企业合作
     * 
     * @param cooperate 企业合作
     * @return 结果
     */
    public int insertCooperate(Cooperate cooperate);

    /**
     * 修改企业合作
     * 
     * @param cooperate 企业合作
     * @return 结果
     */
    public int updateCooperate(Cooperate cooperate);

    /**
     * 批量删除企业合作
     * 
     * @param ids 需要删除的企业合作主键集合
     * @return 结果
     */
    public int deleteCooperateByIds(Long[] ids);

    /**
     * 删除企业合作信息
     * 
     * @param id 企业合作主键
     * @return 结果
     */
    public int deleteCooperateById(Long id);
}
